@@ -1,4 +1,3 @@
-
 from transformers import AutoTokenizer, AutoModelForCausalLM
 import transformers
 import torch
@@ -9,7 +8,7 @@ tokenizer = AutoTokenizer.from_pretrained(model)
 
 model = AutoModelForCausalLM.from_pretrained(model, trust_remote_code=True)
 model.to("mps")
-inputs = tokenizer('test jean', return_tensors="pt").to("mps").input_ids
+inputs = tokenizer("test jean", return_tensors="pt").to("mps").input_ids
 outputs = model.generate(inputs, max_length=200)
 
 print(tokenizer.decode(outputs[0]))
