@@ -4,7 +4,7 @@ from python_search.search.entries_loader import EntriesLoader
 
 
 class ClassifyEntryType(BaseDataTask):
-    PROMPT_START = 'Classify the entry type as one of (Snippet, Url, Cmd, File) in the following content: '
+    PROMPT_START = "Classify the entry type as one of (Snippet, Url, Cmd, File) in the following content: "
 
     def prompt(self, key, content):
         return f"{self.PROMPT_START} key={key} content={content}"
@@ -15,11 +15,11 @@ class ClassifyEntryType(BaseDataTask):
         result = []
         for entry in entries:
             type = entry.get_type_str()
-            if type in ['callable']:
+            if type in ["callable"]:
                 continue
 
-            if type == 'cli_cmd':
-                type = 'Cmd'
+            if type == "cli_cmd":
+                type = "Cmd"
 
             type = type.capitalize()
 
@@ -28,14 +28,14 @@ class ClassifyEntryType(BaseDataTask):
         df = get_spark().createDataFrame(result, ["prompt", "label"])
         print("Entry classifier base dataset size: " + str(df.count()))
 
-
         from python_search.ps_llm.llm_dataset import LLMDataset
-        return df.limit(LLMDataset.MAX_SIZE_PER_TASK_TRAIN_DATASET)
 
+        return df.limit(LLMDataset.MAX_SIZE_PER_TASK_TRAIN_DATASET)
 
     @staticmethod
     def start_with_model():
         from python_search.ps_llm.t5.t5_model import T5Model
+
         instance = ClassifyEntryType()
         model = T5Model.load_productionalized_model()
         instance.model = model
@@ -51,12 +51,7 @@ class ClassifyEntryType(BaseDataTask):
         return result
 
 
-
-
 if __name__ == "__main__":
     import fire
+
     fire.Fire(ClassifyEntryType)
-
-
-
-
