@@ -4,13 +4,12 @@ from python_search.search.entries_loader import EntriesLoader
 
 
 class EntryTitleGenerator(BaseDataTask):
-    PROMPT_START = 'Generate the title for an entry with the following content: '
+    PROMPT_START = "Generate the title for an entry with the following content: "
 
     def prompt(self, content):
         return f"{self.PROMPT_START} {content}"
 
     def build_dataset(self):
-
         entries = EntriesLoader.load_privacy_neutral_only()
 
         result = []
@@ -22,14 +21,11 @@ class EntryTitleGenerator(BaseDataTask):
         df = get_spark().createDataFrame(result, ["prompt", "label"])
 
         from python_search.ps_llm.llm_dataset import LLMDataset
-        return df.limit(LLMDataset.MAX_SIZE_PER_TASK_TRAIN_DATASET)
 
+        return df.limit(LLMDataset.MAX_SIZE_PER_TASK_TRAIN_DATASET)
 
 
 if __name__ == "__main__":
     import fire
+
     fire.Fire(EntryTitleGenerator)
-
-
-
-
